//Source file: PAMAAEventData.java
//Date: June 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.6.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the input data for subscribing to agent assignments from an identity. The event is registered for changes in any of the named agents. If no agents are named, then the event is registered for any agent.
 * 
 */
public final class PAMAAEventData implements java.io.Serializable {

    private String[] identityName;
    private String[] identityType;
    private String[] agentName;
    private String[] agentType;

    /**
     * Creates a new PAMAAEventData instance.
     */
    public PAMAAEventData () {}

    /**
     * Creates a new PAMAAEventData instance.
     * @param _identityName   Specifies the name of the identity for which the assignment is to be notified. Can be an empty array if notification is required for any identity instance.
     * @param _identityType   Specifies the type of the identity for which this notification is requested if the identityName is specified as an empty array. Can be an empty array if notification required for identities of any type.
     * @param _agentName   Specifies the name of the agent whose assignment is to be notified. Can be an empty array.
     * @param _agentType   Specifies the type of the agent for which this notification is requested if agentName is an empty array. Can be an empty array if notification required for agents of any type.
     */
    public PAMAAEventData (String[] _identityName, String[] _identityType, String[] _agentName, String[] _agentType) {

        this.identityName = _identityName;
        this.identityType = _identityType;
        this.agentName = _agentName;
        this.agentType = _agentType;
    }

    /**
     * This method returns a identityName.
     * 
     * @return a String[] value
     */
    public String[] getIdentityName() {
        return identityName;
    }

    /**
     * This method returns a identityType.
     * 
     * @return a String[] value
     */
    public String[] getIdentityType() {
        return identityType;
    }

    /**
     * This method returns a agentName.
     * 
     * @return a String[] value
     */
    public String[] getAgentName() {
        return agentName;
    }

    /**
     * This method returns a agentType.
     * 
     * @return a String[] value
     */
    public String[] getAgentType() {
        return agentType;
    }


    /**
     * This method sets a identityName.
     */ 
    public void setIdentityName(String[] identityName) {
        this.identityName = identityName;
    }

    /**
     * This method sets a identityType.
     */ 
    public void setIdentityType(String[] identityType) {
        this.identityType = identityType;
    }

    /**
     * This method sets a agentName.
     */ 
    public void setAgentName(String[] agentName) {
        this.agentName = agentName;
    }

    /**
     * This method sets a agentType.
     */ 
    public void setAgentType(String[] agentType) {
        this.agentType = agentType;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMAAEventData)) {
            return false;
        } 
        PAMAAEventData pAMAAEventData = (PAMAAEventData) o;
        if(!(this.identityName == pAMAAEventData.identityName))  {
            return false;
        }
        if(!(this.agentName == pAMAAEventData.agentName))  {
            return false;
        }
        if(!(this.agentType == pAMAAEventData.agentType))  {
            return false;
        }
        if(!(this.identityType == pAMAAEventData.identityType))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMAAEventData

