//Source file: PAMACLDefault.java
//Date: June 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.6.0

package org.csapi.jr.se.pam;

/**
 * Defines the two possible default policies for access control.
 *
 */
public final class PAMACLDefault implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static PAMACLDefault[] _array = new PAMACLDefault[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private PAMACLDefault(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Allow access by default
     */
    public static final int _PAM_ACCESS_ALLOW =  0;

    /**
     * Allow access by default
     */
    public static final PAMACLDefault PAM_ACCESS_ALLOW = new PAMACLDefault(_PAM_ACCESS_ALLOW);

    /**
     * Deny access by default
     */
    public static final int _PAM_ACCESS_DENY =  1;

    /**
     * Deny access by default
     */
    public static final PAMACLDefault PAM_ACCESS_DENY = new PAMACLDefault(_PAM_ACCESS_DENY);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved PAMACLDefault object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the PAMACLDefault object
     */
    public String getValueText() {
        switch (_value) {
            case _PAM_ACCESS_ALLOW:
                return "PAM_ACCESS_ALLOW";
            case _PAM_ACCESS_DENY:
                return "PAM_ACCESS_DENY";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static PAMACLDefault getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMACLDefault)) {
            return false;
        }
        PAMACLDefault pAMACLDefault = (PAMACLDefault) o; 
        if(!(this.getValue() == pAMACLDefault.getValue())) {
            return false;
        }
        if (this.hashCode() != pAMACLDefault.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMACLDefault

