//Source file: PAMAccessControlData.java
//Date: June 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.6.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements for access control data.
 * 
 */
public final class PAMAccessControlData implements java.io.Serializable {

    private org.csapi.jr.se.pam.PAMACLDefault defaultPolicy;
    private String[] allowList;
    private String[] denyList;

    /**
     * Creates a new PAMAccessControlData instance.
     */
    public PAMAccessControlData () {}

    /**
     * Creates a new PAMAccessControlData instance.
     * @param _defaultPolicy   Specifies whether the default policy is to allow or deny access for names not mentioned in the list 
     * @param _allowList   Specifies a list of identities to be allowed access
     * @param _denyList   Specifies a list of identities to be denied access
     */
    public PAMAccessControlData (org.csapi.jr.se.pam.PAMACLDefault _defaultPolicy, String[] _allowList, String[] _denyList) {

        this.defaultPolicy = _defaultPolicy;
        this.allowList = _allowList;
        this.denyList = _denyList;
    }

    /**
     * This method returns a defaultPolicy.
     * 
     * @return a org.csapi.jr.se.pam.PAMACLDefault value
     */
    public org.csapi.jr.se.pam.PAMACLDefault getDefaultPolicy() {
        return defaultPolicy;
    }

    /**
     * This method returns a allowList.
     * 
     * @return a String[] value
     */
    public String[] getAllowList() {
        return allowList;
    }

    /**
     * This method returns a denyList.
     * 
     * @return a String[] value
     */
    public String[] getDenyList() {
        return denyList;
    }


    /**
     * This method sets a defaultPolicy.
     */ 
    public void setDefaultPolicy(org.csapi.jr.se.pam.PAMACLDefault defaultPolicy) {
        this.defaultPolicy = defaultPolicy;
    }

    /**
     * This method sets a allowList.
     */ 
    public void setAllowList(String[] allowList) {
        this.allowList = allowList;
    }

    /**
     * This method sets a denyList.
     */ 
    public void setDenyList(String[] denyList) {
        this.denyList = denyList;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMAccessControlData)) {
            return false;
        } 
        PAMAccessControlData pAMAccessControlData = (PAMAccessControlData) o;
        if ((this.defaultPolicy != null) && (pAMAccessControlData.defaultPolicy != null)) {
            if(!(this.defaultPolicy.equals(pAMAccessControlData.defaultPolicy))) {
                return false;
            }
        }
        if(!(this.allowList == pAMAccessControlData.allowList))  {
            return false;
        }
        if(!(this.denyList == pAMAccessControlData.denyList))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMAccessControlData

