//Source file: PAMAttribute.java
//Date: June 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.6.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements containing the attribute name, expiration time and value. This is derived from the common attribute type TpAttribute to add the expiration value for dynamic attributes. 
 * 
 */
public final class PAMAttribute implements java.io.Serializable {

    private String attributeName;
    private org.csapi.jr.se.AttributeValue attributeValue;
    private long expiresIn;

    /**
     * Creates a new PAMAttribute instance.
     */
    public PAMAttribute () {}

    /**
     * Creates a new PAMAttribute instance.
     * @param _attributeName   The name of the attribute.
     * @param _attributeValue   The typed value(s) for the attribute. 
     * @param _expiresIn   The interval in milliseconds in which the attribute values are valid. A time interval of PAM_MAX_LONGINT indicates static attribute values that never expire. A time interval of 0 or negative values indicate an expired value and the time for which it has expired.
     */
    public PAMAttribute (String _attributeName, org.csapi.jr.se.AttributeValue _attributeValue, long _expiresIn) {

        this.attributeName = _attributeName;
        this.attributeValue = _attributeValue;
        this.expiresIn = _expiresIn;
    }

    /**
     * This method returns a attributeName.
     * 
     * @return a String value
     */
    public String getAttributeName() {
        return attributeName;
    }

    /**
     * This method returns a attributeValue.
     * 
     * @return a org.csapi.jr.se.AttributeValue value
     */
    public org.csapi.jr.se.AttributeValue getAttributeValue() {
        return attributeValue;
    }

    /**
     * This method returns a expiresIn.
     * 
     * @return a long value
     */
    public long getExpiresIn() {
        return expiresIn;
    }


    /**
     * This method sets a attributeName.
     */ 
    public void setAttributeName(String attributeName) {
        this.attributeName = attributeName;
    }

    /**
     * This method sets a attributeValue.
     */ 
    public void setAttributeValue(org.csapi.jr.se.AttributeValue attributeValue) {
        this.attributeValue = attributeValue;
    }

    /**
     * This method sets a expiresIn.
     */ 
    public void setExpiresIn(long expiresIn) {
        this.expiresIn = expiresIn;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMAttribute)) {
            return false;
        } 
        PAMAttribute pAMAttribute = (PAMAttribute) o;
        if ((this.attributeValue != null) && (pAMAttribute.attributeValue != null)) {
            if(!(this.attributeValue.equals(pAMAttribute.attributeValue))) {
                return false;
            }
        }
        if(!(this.expiresIn == pAMAttribute.expiresIn))  {
            return false;
        }
        if ((this.attributeName != null) && (pAMAttribute.attributeName != null)) {
            if(!(this.attributeName.equals(pAMAttribute.attributeName)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMAttribute

