//Source file: PAMCCEventData.java
//Date: June 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.6.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the input data for subscribing to identity capability changed events. The event is registered for changes in any of the named capabilities. If no capabilities are named, then the event is registered for all capabilities.
 * 
 */
public final class PAMCCEventData implements java.io.Serializable {

    private String[] identityName;
    private String[] identityType;
    private String[] capabilities;

    /**
     * Creates a new PAMCCEventData instance.
     */
    public PAMCCEventData () {}

    /**
     * Creates a new PAMCCEventData instance.
     * @param _identityName   Specifies the name of the identity for which the capability change is to be notified. Can be an empty array if notification is required for any identity instance
     * @param _identityType   Specifies the type of the identity for which this notification is requested if the identityName is specified as an empty array. Can be an empty array if notification required for identities of any type.
     * @param _capabilities   Specifies the capabilities of interest. Can be an empty array if notifications are required for any capability.
     */
    public PAMCCEventData (String[] _identityName, String[] _identityType, String[] _capabilities) {

        this.identityName = _identityName;
        this.identityType = _identityType;
        this.capabilities = _capabilities;
    }

    /**
     * This method returns a identityName.
     * 
     * @return a String[] value
     */
    public String[] getIdentityName() {
        return identityName;
    }

    /**
     * This method returns a identityType.
     * 
     * @return a String[] value
     */
    public String[] getIdentityType() {
        return identityType;
    }

    /**
     * This method returns a capabilities.
     * 
     * @return a String[] value
     */
    public String[] getCapabilities() {
        return capabilities;
    }


    /**
     * This method sets a identityName.
     */ 
    public void setIdentityName(String[] identityName) {
        this.identityName = identityName;
    }

    /**
     * This method sets a identityType.
     */ 
    public void setIdentityType(String[] identityType) {
        this.identityType = identityType;
    }

    /**
     * This method sets a capabilities.
     */ 
    public void setCapabilities(String[] capabilities) {
        this.capabilities = capabilities;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMCCEventData)) {
            return false;
        } 
        PAMCCEventData pAMCCEventData = (PAMCCEventData) o;
        if(!(this.identityName == pAMCCEventData.identityName))  {
            return false;
        }
        if(!(this.capabilities == pAMCCEventData.capabilities))  {
            return false;
        }
        if(!(this.identityType == pAMCCEventData.identityType))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMCCEventData

