//Source file: PAMCCNotificationData.java
//Date: June 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.6.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the data that is provided in the notifications for capability change events.
 * 
 */
public final class PAMCCNotificationData implements java.io.Serializable {

    private String identity;
    private String[] capabilities;

    /**
     * Creates a new PAMCCNotificationData instance.
     */
    public PAMCCNotificationData () {}

    /**
     * Creates a new PAMCCNotificationData instance.
     * @param _identity   Contains the name of the identity whose capability has changed.
     * @param _capabilities   Contains the capabilities that have changed (that is added or removed).
     */
    public PAMCCNotificationData (String _identity, String[] _capabilities) {

        this.identity = _identity;
        this.capabilities = _capabilities;
    }

    /**
     * This method returns a identity.
     * 
     * @return a String value
     */
    public String getIdentity() {
        return identity;
    }

    /**
     * This method returns a capabilities.
     * 
     * @return a String[] value
     */
    public String[] getCapabilities() {
        return capabilities;
    }


    /**
     * This method sets a identity.
     */ 
    public void setIdentity(String identity) {
        this.identity = identity;
    }

    /**
     * This method sets a capabilities.
     */ 
    public void setCapabilities(String[] capabilities) {
        this.capabilities = capabilities;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMCCNotificationData)) {
            return false;
        } 
        PAMCCNotificationData pAMCCNotificationData = (PAMCCNotificationData) o;
        if(!(this.identity == pAMCCNotificationData.identity))  {
            return false;
        }
        if(!(this.capabilities == pAMCCNotificationData.capabilities))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMCCNotificationData

