//Source file: PAMContext.java
//Date: June 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.6.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements containing the data which defines the context in which an availability is queried and information about the asker that is requesting the data. 
.
 * 
 */
public final class PAMContext implements java.io.Serializable {

    private org.csapi.jr.se.pam.PAMContextData contextData;
    private org.csapi.jr.se.Attribute[] askerData;

    /**
     * Creates a new PAMContext instance.
     */
    public PAMContext () {}

    /**
     * Creates a new PAMContext instance.
     * @param _contextData   Contains the context name and the list of attributes that define the context. The attributes to be included for a given context are specified by the definition of the context.
     * @param _askerData   Contains information about the asker of availability. The exact attributes in this list are dependent on the application. PAM reserves the attribute 'name' with type TpPAMFQName to contain the identity of the asker if known.
     */
    public PAMContext (org.csapi.jr.se.pam.PAMContextData _contextData, org.csapi.jr.se.Attribute[] _askerData) {

        this.contextData = _contextData;
        this.askerData = _askerData;
    }

    /**
     * This method returns a contextData.
     * 
     * @return a org.csapi.jr.se.pam.PAMContextData value
     */
    public org.csapi.jr.se.pam.PAMContextData getContextData() {
        return contextData;
    }

    /**
     * This method returns a askerData.
     * 
     * @return a org.csapi.jr.se.Attribute[] value
     */
    public org.csapi.jr.se.Attribute[] getAskerData() {
        return askerData;
    }


    /**
     * This method sets a contextData.
     */ 
    public void setContextData(org.csapi.jr.se.pam.PAMContextData contextData) {
        this.contextData = contextData;
    }

    /**
     * This method sets a askerData.
     */ 
    public void setAskerData(org.csapi.jr.se.Attribute[] askerData) {
        this.askerData = askerData;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMContext)) {
            return false;
        } 
        PAMContext pAMContext = (PAMContext) o;
        if(!(this.askerData == pAMContext.askerData))  {
            return false;
        }
        if ((this.contextData != null) && (pAMContext.contextData != null)) {
            if(!(this.contextData.equals(pAMContext.contextData))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMContext

