//Source file: PAMEventName.java
//Date: June 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.6.0

package org.csapi.jr.se.pam;

/**
 * This data type identifies the values that specify the event names. 
 *
 */
public final class PAMEventName implements java.io.Serializable {

    private int _value;
    private static int _size = 13;
    private static PAMEventName[] _array = new PAMEventName[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private PAMEventName(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Notify if a new identity has been created
     */
    public static final int _PAM_CE_IDENTITY_CREATED =  0;

    /**
     * Notify if a new identity has been created
     */
    public static final PAMEventName PAM_CE_IDENTITY_CREATED = new PAMEventName(_PAM_CE_IDENTITY_CREATED);

    /**
     * Notify if an identity has been deleted
     */
    public static final int _PAM_CE_IDENTITY_DELETED =  1;

    /**
     * Notify if an identity has been deleted
     */
    public static final PAMEventName PAM_CE_IDENTITY_DELETED = new PAMEventName(_PAM_CE_IDENTITY_DELETED);

    /**
     * Notify if the membership of a group changes.
     */
    public static final int _PAM_CE_GROUP_MEMBERSHIP_CHANGED =  2;

    /**
     * Notify if the membership of a group changes.
     */
    public static final PAMEventName PAM_CE_GROUP_MEMBERSHIP_CHANGED = new PAMEventName(_PAM_CE_GROUP_MEMBERSHIP_CHANGED);

    /**
     * Notify if a new agent has been created
     */
    public static final int _PAM_CE_AGENT_CREATED =  3;

    /**
     * Notify if a new agent has been created
     */
    public static final PAMEventName PAM_CE_AGENT_CREATED = new PAMEventName(_PAM_CE_AGENT_CREATED);

    /**
     * Notify if an agent has been deleted
     */
    public static final int _PAM_CE_AGENT_DELETED =  4;

    /**
     * Notify if an agent has been deleted
     */
    public static final PAMEventName PAM_CE_AGENT_DELETED = new PAMEventName(_PAM_CE_AGENT_DELETED);

    /**
     * Notify if an agent is assigned to an identity
     */
    public static final int _PAM_CE_AGENT_ASSIGNED =  5;

    /**
     * Notify if an agent is assigned to an identity
     */
    public static final PAMEventName PAM_CE_AGENT_ASSIGNED = new PAMEventName(_PAM_CE_AGENT_ASSIGNED);

    /**
     * Notify if an agent has been unassigned from an identity
     */
    public static final int _PAM_CE_AGENT_UNASSIGNED =  6;

    /**
     * Notify if an agent has been unassigned from an identity
     */
    public static final PAMEventName PAM_CE_AGENT_UNASSIGNED = new PAMEventName(_PAM_CE_AGENT_UNASSIGNED);

    /**
     * Notify if the capability of an identity changes
     */
    public static final int _PAM_CE_CAPABILITY_CHANGED =  7;

    /**
     * Notify if the capability of an identity changes
     */
    public static final PAMEventName PAM_CE_CAPABILITY_CHANGED = new PAMEventName(_PAM_CE_CAPABILITY_CHANGED);

    /**
     * Notify if the value of presence attributes of an agent is explicitly set
     */
    public static final int _PAM_CE_AGENT_CAPABILITY_PRESENCE_SET =  8;

    /**
     * Notify if the value of presence attributes of an agent is explicitly set
     */
    public static final PAMEventName PAM_CE_AGENT_CAPABILITY_PRESENCE_SET = new PAMEventName(_PAM_CE_AGENT_CAPABILITY_PRESENCE_SET);

    /**
     * Notify if the value of presence attributes of an agent is explicitly set
     */
    public static final int _PAM_CE_AGENT_PRESENCE_SET =  9;

    /**
     * Notify if the value of presence attributes of an agent is explicitly set
     */
    public static final PAMEventName PAM_CE_AGENT_PRESENCE_SET = new PAMEventName(_PAM_CE_AGENT_PRESENCE_SET);

    /**
     * Notify if the value of presence attributes of an identity is explicitly set
     */
    public static final int _PAM_CE_IDENTITY_PRESENCE_SET =  10;

    /**
     * Notify if the value of presence attributes of an identity is explicitly set
     */
    public static final PAMEventName PAM_CE_IDENTITY_PRESENCE_SET = new PAMEventName(_PAM_CE_IDENTITY_PRESENCE_SET);

    /**
     * Notify if the availability of an identity changes
     */
    public static final int _PAM_CE_AVAILABILITY_CHANGED =  11;

    /**
     * Notify if the availability of an identity changes
     */
    public static final PAMEventName PAM_CE_AVAILABILITY_CHANGED = new PAMEventName(_PAM_CE_AVAILABILITY_CHANGED);

    /**
     * Notify if the current set of watchers change
     */
    public static final int _PAM_CE_WATCHERS_CHANGED =  12;

    /**
     * Notify if the current set of watchers change
     */
    public static final PAMEventName PAM_CE_WATCHERS_CHANGED = new PAMEventName(_PAM_CE_WATCHERS_CHANGED);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved PAMEventName object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the PAMEventName object
     */
    public String getValueText() {
        switch (_value) {
            case _PAM_CE_IDENTITY_CREATED:
                return "PAM_CE_IDENTITY_CREATED";
            case _PAM_CE_IDENTITY_DELETED:
                return "PAM_CE_IDENTITY_DELETED";
            case _PAM_CE_GROUP_MEMBERSHIP_CHANGED:
                return "PAM_CE_GROUP_MEMBERSHIP_CHANGED";
            case _PAM_CE_AGENT_CREATED:
                return "PAM_CE_AGENT_CREATED";
            case _PAM_CE_AGENT_DELETED:
                return "PAM_CE_AGENT_DELETED";
            case _PAM_CE_AGENT_ASSIGNED:
                return "PAM_CE_AGENT_ASSIGNED";
            case _PAM_CE_AGENT_UNASSIGNED:
                return "PAM_CE_AGENT_UNASSIGNED";
            case _PAM_CE_CAPABILITY_CHANGED:
                return "PAM_CE_CAPABILITY_CHANGED";
            case _PAM_CE_AGENT_CAPABILITY_PRESENCE_SET:
                return "PAM_CE_AGENT_CAPABILITY_PRESENCE_SET";
            case _PAM_CE_AGENT_PRESENCE_SET:
                return "PAM_CE_AGENT_PRESENCE_SET";
            case _PAM_CE_IDENTITY_PRESENCE_SET:
                return "PAM_CE_IDENTITY_PRESENCE_SET";
            case _PAM_CE_AVAILABILITY_CHANGED:
                return "PAM_CE_AVAILABILITY_CHANGED";
            case _PAM_CE_WATCHERS_CHANGED:
                return "PAM_CE_WATCHERS_CHANGED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 12
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static PAMEventName getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMEventName)) {
            return false;
        }
        PAMEventName pAMEventName = (PAMEventName) o; 
        if(!(this.getValue() == pAMEventName.getValue())) {
            return false;
        }
        if (this.hashCode() != pAMEventName.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMEventName

