//Source file: PAMIPSEventData.java
//Date: June 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.6.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the input data for subscribing to identity presence set events. The event is registered for changes in any of the named attributes. If no attributes are named, then the event is registered for all attributes in the presence information.
 * 
 */
public final class PAMIPSEventData implements java.io.Serializable {

    private String[] identityName;
    private String[] identityType;
    private String[] attributeNames;
    private long reportingPeriod;

    /**
     * Creates a new PAMIPSEventData instance.
     */
    public PAMIPSEventData () {}

    /**
     * Creates a new PAMIPSEventData instance.
     * @param _identityName   Specifies the name of the identity for which the assignment is to be notified. Can be an empty array if notification is required for any identity instance.
     * @param _identityType   Specifies the type of the identity for which this notification is requested if the identityName is specified as an empty array. Can be an empty array if notification required for identities of any type.
     * @param _attributeNames   Specifies attributes of interest. Can be an empty array
     * @param _reportingPeriod   Specifies the interval for periodic reporting (regardless of change). If -1, the event notification happens only on a change. If 0, there is a single immediate notification even if there is no change. For all other values, there is a periodic notification at the specified time interval regardless of change.
     */
    public PAMIPSEventData (String[] _identityName, String[] _identityType, String[] _attributeNames, long _reportingPeriod) {

        this.identityName = _identityName;
        this.identityType = _identityType;
        this.attributeNames = _attributeNames;
        this.reportingPeriod = _reportingPeriod;
    }

    /**
     * This method returns a identityName.
     * 
     * @return a String[] value
     */
    public String[] getIdentityName() {
        return identityName;
    }

    /**
     * This method returns a identityType.
     * 
     * @return a String[] value
     */
    public String[] getIdentityType() {
        return identityType;
    }

    /**
     * This method returns a attributeNames.
     * 
     * @return a String[] value
     */
    public String[] getAttributeNames() {
        return attributeNames;
    }

    /**
     * This method returns a reportingPeriod.
     * 
     * @return a long value
     */
    public long getReportingPeriod() {
        return reportingPeriod;
    }


    /**
     * This method sets a identityName.
     */ 
    public void setIdentityName(String[] identityName) {
        this.identityName = identityName;
    }

    /**
     * This method sets a identityType.
     */ 
    public void setIdentityType(String[] identityType) {
        this.identityType = identityType;
    }

    /**
     * This method sets a attributeNames.
     */ 
    public void setAttributeNames(String[] attributeNames) {
        this.attributeNames = attributeNames;
    }

    /**
     * This method sets a reportingPeriod.
     */ 
    public void setReportingPeriod(long reportingPeriod) {
        this.reportingPeriod = reportingPeriod;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMIPSEventData)) {
            return false;
        } 
        PAMIPSEventData pAMIPSEventData = (PAMIPSEventData) o;
        if(!(this.identityName == pAMIPSEventData.identityName))  {
            return false;
        }
        if(!(this.reportingPeriod == pAMIPSEventData.reportingPeriod))  {
            return false;
        }
        if(!(this.attributeNames == pAMIPSEventData.attributeNames))  {
            return false;
        }
        if(!(this.identityType == pAMIPSEventData.identityType))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMIPSEventData

