//Source file: PAMWCNotificationData.java
//Date: June 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.6.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the data that is provided in the notifications for watchers changed events.
 * 
 */
public final class PAMWCNotificationData implements java.io.Serializable {

    private org.csapi.jr.se.pam.PAMEventName event;
    private org.csapi.jr.se.pam.PAMwatcherChangeType changeType;
    private String identity;
    private String[] watchers;

    /**
     * Creates a new PAMWCNotificationData instance.
     */
    public PAMWCNotificationData () {}

    /**
     * Creates a new PAMWCNotificationData instance.
     * @param _event   Contains the name of the event for which the watchers changed.
     * @param _changeType   Specifies whether the listed watchers were added or deleted
     * @param _identity   Contains the name of the identity whose capability has changed.
     * @param _watchers   Contains the list of watchers involved in the change.
     */
    public PAMWCNotificationData (org.csapi.jr.se.pam.PAMEventName _event, org.csapi.jr.se.pam.PAMwatcherChangeType _changeType, String _identity, String[] _watchers) {

        this.event = _event;
        this.changeType = _changeType;
        this.identity = _identity;
        this.watchers = _watchers;
    }

    /**
     * This method returns a event.
     * 
     * @return a org.csapi.jr.se.pam.PAMEventName value
     */
    public org.csapi.jr.se.pam.PAMEventName getEvent() {
        return event;
    }

    /**
     * This method returns a changeType.
     * 
     * @return a org.csapi.jr.se.pam.PAMwatcherChangeType value
     */
    public org.csapi.jr.se.pam.PAMwatcherChangeType getChangeType() {
        return changeType;
    }

    /**
     * This method returns a identity.
     * 
     * @return a String value
     */
    public String getIdentity() {
        return identity;
    }

    /**
     * This method returns a watchers.
     * 
     * @return a String[] value
     */
    public String[] getWatchers() {
        return watchers;
    }


    /**
     * This method sets a event.
     */ 
    public void setEvent(org.csapi.jr.se.pam.PAMEventName event) {
        this.event = event;
    }

    /**
     * This method sets a changeType.
     */ 
    public void setChangeType(org.csapi.jr.se.pam.PAMwatcherChangeType changeType) {
        this.changeType = changeType;
    }

    /**
     * This method sets a identity.
     */ 
    public void setIdentity(String identity) {
        this.identity = identity;
    }

    /**
     * This method sets a watchers.
     */ 
    public void setWatchers(String[] watchers) {
        this.watchers = watchers;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMWCNotificationData)) {
            return false;
        } 
        PAMWCNotificationData pAMWCNotificationData = (PAMWCNotificationData) o;
        if ((this.event != null) && (pAMWCNotificationData.event != null)) {
            if(!(this.event.equals(pAMWCNotificationData.event))) {
                return false;
            }
        }
        if ((this.changeType != null) && (pAMWCNotificationData.changeType != null)) {
            if(!(this.changeType.equals(pAMWCNotificationData.changeType))) {
                return false;
            }
        }
        if(!(this.identity == pAMWCNotificationData.identity))  {
            return false;
        }
        if(!(this.watchers == pAMWCNotificationData.watchers))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMWCNotificationData

